Changelog
=========


(unreleased)
------------
- - add config `app_prefix` for evo router. [maycuatroi]
- - lint code. [maycuatroi]
- Merge remote-tracking branch 'origin/main' [maycuatroi]
- Update LICENSE. [Nguyễn Anh Bình]
- - Update code create relase. [maycuatroi]


0.0.11 (2024-04-15)
-------------------
- Bump version to 0.0.11. [maycuatroi]


0.0.10 (2024-04-15)
-------------------
- Bump version to 0.0.10. [Nguyen Anh Binh]
- - update create release script. [Nguyen Anh Binh]
- Bump version to 0.0.9. [Nguyen Anh Binh]
- Bump version to 0.0.8. [Nguyen Anh Binh]
- Bump version to 0.0.7. [Nguyen Anh Binh]
- Bump version to 0.0.6. [Nguyen Anh Binh]
- Bump version to 0.0.5. [Nguyen Anh Binh]
- Bump version to 0.0.4. [Nguyen Anh Binh]
- - add missing libs. [Binh Nguyen]
- - Add evo-router moduler base. [Binh Nguyen]
- - pump version. [Nguyễn Anh Bình]
- - pump version. [Nguyễn Anh Bình]
- - remove template readme. [Nguyễn Anh Bình]
- - test linux only. [Nguyễn Anh Bình]
- - remove old workflow. [Nguyễn Anh Bình]
- - first commit. [Nguyễn Anh Bình]
- ✅ Ready to clone and code. [maycuatroi]
- Initial commit. [Nguyễn Anh Bình]


